import axios from 'axios';
import store from '../store/index'
import { Message } from 'element-ui'
import router from '../router/index'
import Setting from '@/setting'

axios.defaults.baseURL = Setting.apiBaseURL
// 请求超时时间
axios.defaults.timeout = 3000000000;

// post请求头
axios.defaults.headers.post['Content-Type'] = 'application/json;charset=UTF-8';

// 请求拦截器
axios.interceptors.request.use(config => {
  let token = sessionStorage.getItem('token')
  if (token) {
    config.headers.token = token
  }
  let schoolId = store.state.schoolId
  if (schoolId) config.headers.schoolId = store.state.schoolId
  return config;
}, err => {
  Message.error({
    message: '退出登陆',
    onClose: function () {
      router.push({ name: 'login' });
    }
  })
  return Promise.reject(err);
})

let logouted = 0;
// 响应拦截器
axios.interceptors.response.use(
  response => {
    if (response.status === 200) {
      const { status, code, msg } = response.data
      if (status) {
        // 接口定义的非正常返回的时候,应当处于报错状态
        if (status === 10020) {
          // 该状态为用户列表启用用户的接口返回的状态，特殊处理
          return Promise.reject(response)
        } else if (status !== 200) {
          Message.error(response.data.message)
          return Promise.reject(response)
        } else {
          return Promise.resolve(response)
        }
      } else if (code === 401) {
        // 账号互踢
        if (!logouted) {
          sessionStorage.removeItem('token')
          Message.error(msg.includes('顶') ? '您的账号已在其他设备登录，您已被迫下线！' : '登录过期，请重新登录！')
          setTimeout(() => {
            router.replace({
              path: '/login',
              query: {
                redirect: router.currentRoute.fullPath
              }
            })
            logouted = 0
          }, 1500)
          logouted = 1
        }
      } else {
        return Promise.resolve(response)
      }
    } else {
      Message.error(response.message, 'res');
      return Promise.reject(response);
    }
  },
  // 服务器状态码不是200的情况
  error => {
    if (error.response.status) {
      switch (error.response.status) {
        // 401: 未登录
        // 未登录则跳转登录页面，并携带当前页面的路径
        // 在登录成功后返回当前页面，这一步需要在登录页操作。
        case 401:
          if (!logouted) {
            Message.error('登录过期，请重新登录!');
            setTimeout(() => {
              router.replace({
                path: '/login',
                query: {
                  redirect: router.currentRoute.fullPath
                }
              });
            }, 1000);
            logouted = 1
          }
          break;
        // 403 token过期
        // 登录过期对用户进行提示
        // 清除本地token和清空vuex中token对象
        // 跳转登录页面
        case 403:
          // 清除token
          sessionStorage.removeItem('token');
          store.commit('loginSuccess', null);
          // 跳转登录页面，并将要浏览的页面fullPath传过去，登录成功后跳转需要访问的页面
          setTimeout(() => {
            router.replace({
              path: '/login',
              query: {
                redirect: router.currentRoute.fullPath
              }
            });
          }, 1000);
          break;
        // 404请求不存在
        case 404:
          Message.error('404网络请求不存在!');
          break;
        case 500:// 网络错误
          Message.error('网络错误!');
          // router.replace({
          //     path: '/login',
          //     query: { redirect: router.currentRoute.fullPath }
          // });
          break;
        // 其他错误，直接抛出错误提示
        default:
          Message.error(error.response.data.message);
          break;
      }
      return Promise.reject(error.response);
    }
  }
);


function logouts () {
  store.replaceState({})
  localStorage.clear()
  sessionStorage.clear()
  location.reload()
}

let tokenStatus = {
  0: '用户未登录，请登录后操作！',
  1: 'token错误，请重新登录！'
}
/**
  * get方法，对应get请求
  */
export function get (url, params) {
  return new Promise((resolve, reject) => {
    axios.get(url, {
      params: params
    })
      .then(res => {
        resolve(res.data)
      })
      .catch(err => {
        reject(err.data)
      })
  });
}
/**
  * post方法，对应post请求
  */
export function post (url, params, config) {
  return new Promise((resolve, reject) => {
    axios.post(url, params, config)
      .then(res => {
        return resolve(res.data);
      })
      .catch(err => {
        return reject(err.data)
      })
  });
}

/**
  * delete方法，对应delete请求
  */
export function del (url, params) {
  return new Promise((resolve, reject) => {
    axios.delete(url, {
      params: params
    })
      .then(res => {
        resolve(res.data);
      })
      .catch(err => {
        reject(err.data)
      })
  });
}

/**
 * put修改
 * @param {} url 
 * @param {*} params 
 */
export function put (url, params) {
  return new Promise((resolve, reject) => {
    axios.put(url, params)
      .then(res => {
        resolve(res.data);
      })
      .catch(err => {
        reject(err.data)
      })
  });
}